@@ -207,23 +207,27 @@ class BaseVolume(AbstractVolume):
             try:
                 with os.scandir(target_path) as scanner:
                     for entry in scanner:
+                        symlink_target = ""
                         entry_type = DirEntryType.FILE
                         if entry.is_dir():
                             entry_type = DirEntryType.DIRECTORY
                         if entry.is_symlink():
                             entry_type = DirEntryType.SYMLINK
+                            symlink_target = str(Path(entry).resolve())
+                        entry_stat = entry.stat(follow_symlinks=False)
                         q.put(
                             DirEntry(
                                 name=entry.name,
                                 path=Path(entry.path),
                                 type=entry_type,
                                 stat=Stat(
-                                    size=entry.stat().st_size,
-                                    owner=str(entry.stat().st_uid),
-                                    mode=entry.stat().st_mode,
-                                    modified=fstime2datetime(entry.stat().st_mtime),
-                                    created=fstime2datetime(entry.stat().st_ctime),
+                                    size=entry_stat.st_size,
+                                    owner=str(entry_stat.st_uid),
+                                    mode=entry_stat.st_mode,
+                                    modified=fstime2datetime(entry_stat.st_mtime),
+                                    created=fstime2datetime(entry_stat.st_ctime),
                                 ),
+                                symlink_target=symlink_target,
                             )
                         )
                         count += 1
